from django.db import models
from django.utils import timezone

def convertDuration(totalseconds):
    """
    sekunden in stunden, minuten und eskunden umwandeln
    """
    #eine Stunde hat 3600 sekunden
    hours, reminder = divmod(totalseconds, 3600)
    minutes, seconds = divmod(reminder, 60)
    return (int(hours), int(minutes), int(seconds))

def formatDuration(totalseconds):
    d = convertDuration(totalseconds)
    return "{0}:{1} ".format(d[0], d[1])

# Create your models here.

class Person(models.Model):
    vorname = models.CharField(max_length=200)
    nachname = models.CharField(max_length=200)
    SVNR = models.CharField(max_length=20)
    DStl = models.CharField(max_length=20, blank=True)
    title_pre = models.CharField(max_length=20, blank=True)
    title_suf = models.CharField(max_length=20, blank=True)
    Dgrd = models.CharField(max_length=20, blank=True)

    def __str__(self):
        return "{0} {1} {2} {3} {4}".format(self.Dgrd, self.title_pre,self.nachname, self.vorname, self.title_suf)
    class Meta:
        verbose_name_plural = "Personen"

class Arbeitszeit(models.Model):
    person = models.ForeignKey(Person)
    montag = models.DurationField()
    dienstag = models.DurationField()
    mittwoch = models.DurationField()
    donnerstag  = models.DurationField()
    freitag = models.DurationField()

    @property
    def wo_arb_zeit(self):
        return (self.montag + self.dienstag + self.mittwoch + self.donnerstag + self.freitag).total_seconds()

    def __str__(self):
        return "{0}: Wochenarbeitszeit: {1}".format(self.person, formatDuration(self.wo_arb_zeit))
    class Meta:
        verbose_name_plural = "Arbeitszeiten"

class TimeTable(models.Model):
    person = models.ForeignKey(Person)
    intime = models.DateTimeField()
    outtime = models.DateTimeField()

    @property
    def working_hrs(self):
        self.total_hrs = self.outtime - self.intime
        return self.total_hrs

    @property
    def sel_month(self):
        return self.intime.month

    @property
    def times(self):
        return "{3}:  Ein: {0} Aus: {1} Total: {2}".format(self.intime.strftime('%H:%M'), self.outtime.strftime('%H:%M'), self.working_hrs, self.intime.strftime('%a %d %b %Y,'))


    def __str__(self):
        return "{3}: {0} aus: {1} Total: {2}".format(self.intime.strftime('%a %d %b %Y, %H:%M'), self.outtime.strftime('%H:%M'), self.working_hrs, self.person)

class AbsentReasons(models.Model):
    reason = models.CharField(max_length="100")

class Absent(models.Model):
    #TODO absense Zeizen nur dann von der Arbeitszeit abziehen, wenn  berechtigt, z.B 'Zeitkarte', nicht bei 'Arzt' etc.
    ABSENT_CHOISES = (
        ('ZK-Ausgleich', 'ZK'),
        ('MDL-Ausgleich', 'MDLA'),
        ('Erholungsurlaub', 'EU'),
        ('Pflegeurlaub', 'PU'),
        ('Sonderurlaub', 'SU'),
        ('Arzt', 'A'),
        ('Krank', 'K'),
        ('Kuraufenthalt','Kur'),
        ('', '..Sonstiges'),
    )
    person = models.ForeignKey(Person)
    reason = models.CharField(max_length=100, choices=ABSENT_CHOISES, default="")
    starttime = models.DateTimeField()
    endtime = models.DateTimeField()

    def absence_hrs(self):
        self.abs_time = self.endtime - self.starttime
        return self.abs_time

    def __str__(self):
        return "{4}, Grund: {0}, von {1} bis {2}, Total: {3}".format(self.reason, self.starttime.strftime('%H:%m'), self.endtime.strftime('%H:%m'), self.absence_hrs().__str__(), self.person.nachname)


class TimeDelta(models.Model):
    person = models.ForeignKey(Person)
    pub_date = models.DateField(default=timezone.now())
    s_date = models.DurationField(name="Stand")

    def was_published(self):
        return self.pub_date >= timezone.now()

    def __str__(self):
        return "Stand: {0}, {1}".format(self.person, self.pub_date)